aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/includes/startup.php
diff options
context:
space:
mode:
authorIgor Wiedler <igor@wiedler.ch>2012-03-28 21:48:46 +0200
committerIgor Wiedler <igor@wiedler.ch>2012-03-28 21:48:46 +0200
commit138e7dae0087e683fcb170df1e806b8e4f4b86cd (patch)
tree1dc254d91ecb981f2eddd30de016b34d83febad0 /phpBB/includes/startup.php
parent7f1abaa318cb7008c9eab259003d67790e346094 (diff)
downloadforums-138e7dae0087e683fcb170df1e806b8e4f4b86cd.tar
forums-138e7dae0087e683fcb170df1e806b8e4f4b86cd.tar.gz
forums-138e7dae0087e683fcb170df1e806b8e4f4b86cd.tar.bz2
forums-138e7dae0087e683fcb170df1e806b8e4f4b86cd.tar.xz
forums-138e7dae0087e683fcb170df1e806b8e4f4b86cd.zip
[feature/event-dispatcher] Rename PHPBB_NO_AUTOLOAD=>PHPBB_NO_COMPOSER_AUTOLOAD
PHPBB3-9550
Diffstat (limited to 'phpBB/includes/startup.php')
-rw-r--r--phpBB/includes/startup.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/phpBB/includes/startup.php b/phpBB/includes/startup.php
index 45eaff6fc7..f75d70e366 100644
--- a/phpBB/includes/startup.php
+++ b/phpBB/includes/startup.php
@@ -153,16 +153,16 @@ if (function_exists('date_default_timezone_set') && function_exists('date_defaul
// vendor/.composer/autoload.php. If this file exists it will be
// automatically used by phpBB. This is the default mode that phpBB
// will use when shipped.
// 2. To disable composer autoloading, PHPBB_NO_AUTOLOAD can be specified.
// Additionally specify PHPBB_AUTOLOAD=/path/to/autoload.php in the
// environment. This is useful for running CLI scripts and tests.
// /path/to/autoload.php should define and register class loaders
// for all of phpBB's dependencies.
// 3. You can also set PHPBB_NO_AUTOLOAD without setting PHPBB_AUTOLOAD.
// In this case autoloading needs to be defined before running any phpBB
// script. This might be useful in cases when phpBB is integrated into a
// larger program.
-if (getenv('PHPBB_NO_AUTOLOAD'))
+if (getenv('PHPBB_NO_COMPOSER_AUTOLOAD'))
{
if (getenv('PHPBB_AUTOLOAD'))
{
@@ -153,16 +153,16 @@ if (function_exists('date_default_timezone_set') && function_exists('date_defaul
// automatically used by phpBB. This is the default mode that phpBB
// will use when shipped.
-// 2. To disable composer autoloading, PHPBB_NO_AUTOLOAD can be specified.
+// 2. To disable composer autoloading, PHPBB_NO_COMPOSER_AUTOLOAD can be specified.
// Additionally specify PHPBB_AUTOLOAD=/path/to/autoload.php in the
// environment. This is useful for running CLI scripts and tests.
@@ -153,16 +153,16 @@ if (function_exists('date_default_timezone_set') && function_exists('date_defaul
// /path/to/autoload.php should define and register class loaders
// for all of phpBB's dependencies.
-// 3. You can also set PHPBB_NO_AUTOLOAD without setting PHPBB_AUTOLOAD.
+// 3. You can also set PHPBB_NO_COMPOSER_AUTOLOAD without setting PHPBB_AUTOLOAD.
// In this case autoloading needs to be defined before running any phpBB
// script. This might be useful in cases when phpBB is integrated into a